import React, { useState, useEffect } from 'react';
import Icon from '@graphpolaris/shared/lib/components/icon';
import * as d3 from 'd3';
import { ArrowRightAlt } from '@mui/icons-material';

type EdgeArrayItem = {
  nameRegions: string[];
};

export type SelectionEdgesProps = EdgeArrayItem[];

function handleCheckbox(index: number, checkboxStates: boolean[]) {
  const visibility = !checkboxStates[index] ? 'block' : 'none';
  d3.selectAll(`.edge_region0_to_region${index + 1}`).style('display', visibility);
}

const SelectionEdges: React.FC<SelectionEdgesProps> = (props) => {
  const edgesArray = Array.isArray(props) ? props : (Object.values(props) as EdgeArrayItem[]);

  const [checkboxStates, setCheckboxStates] = useState<boolean[]>([]);

  useEffect(() => {
    // To initialize states
    setCheckboxStates((prevStates) => {
      const newStates = [...prevStates];
      edgesArray.forEach((_, index) => {
        if (newStates[index] === undefined) {
          newStates[index] = true;
        }
      });
      return newStates;
    });
  }, [props]);

  const handleCheckboxChange = (index: number) => {
    setCheckboxStates((prevStates) => {
      const newStates = [...prevStates];
      newStates[index] = !prevStates[index];
      return newStates;
    });
    handleCheckbox(index, checkboxStates);
  };
  return (
    <div className="border border-gray p-4 bg-white rounded flex items-center">
      <ul>
        {edgesArray.map((element: EdgeArrayItem, index: number) => (
          <li key={index}>
            <div className="flex items-center space-x-2">
              <input
                type="checkbox"
                checked={checkboxStates[index]}
                className="checkbox checkbox-sm"
                onChange={() => handleCheckboxChange(index)}
              ></input>
              <div>
                <span>{element.nameRegions[0]}</span>
                <Icon component={<ArrowRightAlt />} size={32} />
                <span>{element.nameRegions[1]}</span>
              </div>
            </div>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default SelectionEdges;
